summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authormycroft <mycroft@NetBSD.org>1995-12-24 02:29:35 +0000
committermycroft <mycroft@NetBSD.org>1995-12-24 02:29:35 +0000
commit3da4b2a160a4a6da74faa992a498b4e4453471c9 (patch)
tree1d8c1545a9941d1846bc7133e294bde85cbf142f /sys
parent1ca89b7f9196cda848f1c282e36d81da24d2af6f (diff)
The IST_* and IPL_* constants are not bus-specific; don't treat them as such.
Change splimp -> splnet in Ethernet, ARCnet, and FDDI drivers.
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/alpha/isa/pckbd.c4
-rw-r--r--sys/arch/alpha/pci/pci_2100_a50.c9
-rw-r--r--sys/arch/alpha/pci/pci_axppci_33.c9
-rw-r--r--sys/arch/alpha/pci/pci_kn20aa.c10
-rw-r--r--sys/arch/alpha/pci/pcivga.c5
-rw-r--r--sys/arch/alpha/pci/sio_pic.c33
-rw-r--r--sys/arch/amiga/dev/if_ae.c6
-rw-r--r--sys/arch/amiga/dev/if_bah.c16
-rw-r--r--sys/arch/amiga/dev/if_ed.c10
-rw-r--r--sys/arch/amiga/dev/if_es.c10
-rw-r--r--sys/arch/amiga/dev/if_qn.c6
-rw-r--r--sys/arch/i386/isa/clock.c5
-rw-r--r--sys/arch/i386/isa/fd.c6
-rw-r--r--sys/arch/i386/isa/isa_machdep.c61
-rw-r--r--sys/arch/i386/isa/lms.c6
-rw-r--r--sys/arch/i386/isa/mms.c6
-rw-r--r--sys/arch/i386/isa/npx.c6
-rw-r--r--sys/arch/i386/isa/pccons.c6
-rw-r--r--sys/arch/i386/isa/pcvt/pcvt_drv.c4
-rw-r--r--sys/arch/i386/isa/pms.c6
-rw-r--r--sys/arch/i386/pci/pci_machdep.c35
-rw-r--r--sys/arch/mac68k/dev/if_ae.c8
-rw-r--r--sys/arch/pmax/dev/if_le.c6
-rw-r--r--sys/arch/sparc/dev/if_ie.c16
-rw-r--r--sys/arch/sun3/dev/if_ie.c16
-rw-r--r--sys/arch/vax/if/if_de.c6
-rw-r--r--sys/arch/vax/if/if_qe.c8
-rw-r--r--sys/dev/ata/wd.c6
-rw-r--r--sys/dev/audio_if.h4
-rw-r--r--sys/dev/eisa/aha1742.c6
-rw-r--r--sys/dev/eisa/eisavar.h12
-rw-r--r--sys/dev/ic/aic6360.c6
-rw-r--r--sys/dev/ic/com.c6
-rw-r--r--sys/dev/ic/lpt.c6
-rw-r--r--sys/dev/ic/lptvar.h6
-rw-r--r--sys/dev/ic/mb86960.c12
-rw-r--r--sys/dev/ic/mb86960var.h12
-rw-r--r--sys/dev/ic/smc90cx6.c16
-rw-r--r--sys/dev/isa/aha1542.c6
-rw-r--r--sys/dev/isa/aic6360.c6
-rw-r--r--sys/dev/isa/ast.c6
-rw-r--r--sys/dev/isa/boca.c6
-rw-r--r--sys/dev/isa/bt742a.c6
-rw-r--r--sys/dev/isa/com.c6
-rw-r--r--sys/dev/isa/gus.c8
-rw-r--r--sys/dev/isa/if_ate.c12
-rw-r--r--sys/dev/isa/if_ed.c12
-rw-r--r--sys/dev/isa/if_eg.c10
-rw-r--r--sys/dev/isa/if_el.c18
-rw-r--r--sys/dev/isa/if_ep.c18
-rw-r--r--sys/dev/isa/if_fe.c12
-rw-r--r--sys/dev/isa/if_fmv.c12
-rw-r--r--sys/dev/isa/if_hp.c10
-rw-r--r--sys/dev/isa/if_ie.c18
-rw-r--r--sys/dev/isa/if_le.c8
-rw-r--r--sys/dev/isa/isa.c12
-rw-r--r--sys/dev/isa/isavar.h24
-rw-r--r--sys/dev/isa/lpt.c6
-rw-r--r--sys/dev/isa/lpt_isa.c6
-rw-r--r--sys/dev/isa/mcd.c6
-rw-r--r--sys/dev/isa/pas.c4
-rw-r--r--sys/dev/isa/pss.c14
-rw-r--r--sys/dev/isa/rtfps.c5
-rw-r--r--sys/dev/isa/sb.c4
-rw-r--r--sys/dev/isa/seagate.c4
-rw-r--r--sys/dev/isa/ultra14f.c4
-rw-r--r--sys/dev/isa/wd.c6
-rw-r--r--sys/dev/isa/wss.c5
-rw-r--r--sys/dev/isa/wt.c6
-rw-r--r--sys/dev/pci/aic7870.c4
-rw-r--r--sys/dev/pci/if_de.c6
-rw-r--r--sys/dev/pci/if_fpa.c4
-rw-r--r--sys/dev/pci/ncr.c6
-rw-r--r--sys/dev/pci/pcivar.h13
74 files changed, 311 insertions, 413 deletions
diff --git a/sys/arch/alpha/isa/pckbd.c b/sys/arch/alpha/isa/pckbd.c
index cea8cd5f5de..ab269620ef7 100644
--- a/sys/arch/alpha/isa/pckbd.c
+++ b/sys/arch/alpha/isa/pckbd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pckbd.c,v 1.2 1995/11/23 02:37:06 cgd Exp $ */
+/* $NetBSD: pckbd.c,v 1.3 1995/12/24 02:29:35 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum. All rights reserved.
@@ -348,7 +348,7 @@ pckbdattach(parent, self, aux)
pckbd_pio_arg = ida->ida_pioarg; /* XXX */
sc->sc_ih = ISA_INTR_ESTABLISH(pckbd_intr_fns, pckbd_intr_arg,
- ida->ida_irq[0], ISA_IST_EDGE, ISA_IPL_TTY, pckbdintr, sc);
+ ida->ida_irq[0], IST_EDGE, IPL_TTY, pckbdintr, sc);
#if NWSC
printf("\n");
wscattach_input(self, self, pccngetc, pccnpollc);
diff --git a/sys/arch/alpha/pci/pci_2100_a50.c b/sys/arch/alpha/pci/pci_2100_a50.c
index c33a9a83b0e..20267d06cce 100644
--- a/sys/arch/alpha/pci/pci_2100_a50.c
+++ b/sys/arch/alpha/pci/pci_2100_a50.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pci_2100_a50.c,v 1.3 1995/11/23 02:37:49 cgd Exp $ */
+/* $NetBSD: pci_2100_a50.c,v 1.4 1995/12/24 02:29:42 mycroft Exp $ */
/*
* Copyright (c) 1995 Carnegie-Mellon University.
@@ -47,7 +47,7 @@
#include "sio.h"
void *dec_2100_a50_pci_map_int __P((void *, pci_conftag_t,
- pci_intr_pin_t, pci_intr_line_t, pci_intrlevel_t,
+ pci_intr_pin_t, pci_intr_line_t, int,
int (*func)(void *), void *));
void dec_2100_a50_pci_unmap_int __P((void *, void *));
@@ -62,7 +62,7 @@ dec_2100_a50_pci_map_int(acv, tag, pin, line, level, func, arg)
pci_conftag_t tag;
pci_intr_pin_t pin;
pci_intr_line_t line;
- pci_intrlevel_t level;
+ int level;
int (*func) __P((void *));
void *arg;
{
@@ -151,8 +151,7 @@ dec_2100_a50_pci_map_int(acv, tag, pin, line, level, func, arg)
#if NSIO
return ISA_INTR_ESTABLISH(&sio_isa_intr_fns, NULL, /* XXX */
- pirqline, ISA_IST_LEVEL, pci_intrlevel_to_isa(level),
- func, arg);
+ pirqline, IST_LEVEL, level, func, arg);
#else
panic("dec_2100_a50_pci_map_int: no sio!");
#endif
diff --git a/sys/arch/alpha/pci/pci_axppci_33.c b/sys/arch/alpha/pci/pci_axppci_33.c
index 74fb338e91f..3f606fd16f8 100644
--- a/sys/arch/alpha/pci/pci_axppci_33.c
+++ b/sys/arch/alpha/pci/pci_axppci_33.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pci_axppci_33.c,v 1.1 1995/11/23 02:37:54 cgd Exp $ */
+/* $NetBSD: pci_axppci_33.c,v 1.2 1995/12/24 02:29:43 mycroft Exp $ */
/*
* Copyright (c) 1995 Carnegie-Mellon University.
@@ -48,7 +48,7 @@
#include "sio.h"
void *dec_axppci_33_pci_map_int __P((void *, pci_conftag_t,
- pci_intr_pin_t, pci_intr_line_t, pci_intrlevel_t,
+ pci_intr_pin_t, pci_intr_line_t, int,
int (*func)(void *), void *));
void dec_axppci_33_pci_unmap_int __P((void *, void *));
@@ -63,7 +63,7 @@ dec_axppci_33_pci_map_int(lcv, tag, pin, line, level, func, arg)
pci_conftag_t tag;
pci_intr_pin_t pin;
pci_intr_line_t line;
- pci_intrlevel_t level;
+ int level;
int (*func) __P((void *));
void *arg;
{
@@ -158,8 +158,7 @@ dec_axppci_33_pci_map_int(lcv, tag, pin, line, level, func, arg)
#if NSIO
return ISA_INTR_ESTABLISH(&sio_isa_intr_fns, NULL, /* XXX */
- pirqline, ISA_IST_LEVEL, pci_intrlevel_to_isa(level),
- func, arg);
+ pirqline, IST_LEVEL, level, func, arg);
#else
panic("dec_axppci_33_pci_map_int: no sio!");
#endif
diff --git a/sys/arch/alpha/pci/pci_kn20aa.c b/sys/arch/alpha/pci/pci_kn20aa.c
index c5c64d636b8..7d521dbeac9 100644
--- a/sys/arch/alpha/pci/pci_kn20aa.c
+++ b/sys/arch/alpha/pci/pci_kn20aa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pci_kn20aa.c,v 1.1 1995/11/23 02:38:00 cgd Exp $ */
+/* $NetBSD: pci_kn20aa.c,v 1.2 1995/12/24 02:29:45 mycroft Exp $ */
/*
* Copyright (c) 1995 Carnegie-Mellon University.
@@ -56,7 +56,7 @@
#endif
void *kn20aa_pci_map_int __P((void *, pci_conftag_t, pci_intr_pin_t,
- pci_intr_line_t, pci_intrlevel_t, int (*func)(void *), void *));
+ pci_intr_line_t, int, int (*func)(void *), void *));
void kn20aa_pci_unmap_int __P((void *, void *));
__const struct pci_intr_fns kn20aa_pci_intr_fns = {
@@ -87,7 +87,7 @@ void kn20aa_pci_strayintr __P((int irq));
void kn20aa_iointr __P((void *framep, int vec));
void kn20aa_enable_intr __P((int irq));
struct kn20aa_intrhand *kn20aa_attach_intr __P((struct kn20aa_intrchain *,
- pci_intrlevel_t, int (*) (void *), void *));
+ int, int (*) (void *), void *));
void
pci_kn20aa_pickintr(pcf, pcfa, ppf, ppfa, pifp, pifap)
@@ -127,7 +127,7 @@ kn20aa_pci_map_int(ccv, tag, pin, line, level, func, arg)
pci_conftag_t tag;
pci_intr_pin_t pin;
pci_intr_line_t line;
- pci_intrlevel_t level;
+ int level;
int (*func) __P((void *));
void *arg;
{
@@ -275,7 +275,7 @@ kn20aa_enable_intr(irq)
struct kn20aa_intrhand *
kn20aa_attach_intr(chain, level, func, arg)
struct kn20aa_intrchain *chain;
- pci_intrlevel_t level;
+ int level;
int (*func) __P((void *));
void *arg;
{
diff --git a/sys/arch/alpha/pci/pcivga.c b/sys/arch/alpha/pci/pcivga.c
index 10b2f3cbbec..049a9d99429 100644
--- a/sys/arch/alpha/pci/pcivga.c
+++ b/sys/arch/alpha/pci/pcivga.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pcivga.c,v 1.3 1995/11/23 02:38:11 cgd Exp $ */
+/* $NetBSD: pcivga.c,v 1.4 1995/12/24 02:29:47 mycroft Exp $ */
/*
* Copyright (c) 1995 Carnegie-Mellon University.
@@ -180,8 +180,7 @@ pcivgaattach(parent, self, aux)
#if 0
pci_intrdata = pci_conf_read(sc->sc_pcitag, PCI_INTERRUPT_REG);
if (PCI_INTERRUPT_PIN(pci_intrdata) != PCI_INTERRUPT_PIN_NONE) {
- sc->sc_intr = pci_map_int(sc->sc_pcitag, PCI_IPL_TTY,
- tgaintr, sc);
+ sc->sc_intr = pci_map_int(sc->sc_pcitag, IPL_TTY, tgaintr, sc);
if (sc->sc_intr == NULL)
printf("%s: WARNING: couldn't map interrupt\n",
sc->sc_dev.dv_xname);
diff --git a/sys/arch/alpha/pci/sio_pic.c b/sys/arch/alpha/pci/sio_pic.c
index ec24ec96c5c..b7d7af43858 100644
--- a/sys/arch/alpha/pci/sio_pic.c
+++ b/sys/arch/alpha/pci/sio_pic.c
@@ -1,4 +1,4 @@
-/* $NetBSD: sio_pic.c,v 1.2 1995/11/23 02:38:19 cgd Exp $ */
+/* $NetBSD: sio_pic.c,v 1.3 1995/12/24 02:29:49 mycroft Exp $ */
/*
* Copyright (c) 1995 Carnegie-Mellon University.
@@ -57,8 +57,7 @@
* Private functions and variables.
*/
static void *sio_intr_establish __P((void *, isa_irq_t,
- isa_intrsharetype_t, isa_intrlevel_t,
- int (*)(void *), void *));
+ int, int, int (*)(void *), void *));
static void sio_intr_disestablish __P((void *, void *));
static void sio_strayintr __P((isa_irq_t));
@@ -89,7 +88,7 @@ struct intrhand {
#define ICU_LEN 16 /* number of ISA IRQs */
static struct intrhand *sio_intrhand[ICU_LEN];
-static isa_intrsharetype_t sio_intrsharetype[ICU_LEN];
+static int sio_intrsharetype[ICU_LEN];
static u_long sio_strayintrcnt[ICU_LEN];
#ifdef EVCNT_COUNTERS
struct evcnt sio_intr_evcnt;
@@ -126,7 +125,7 @@ u_int8_t initial_elcr[2];
void
sio_setirqstat(irq, enabled, type)
int irq, enabled;
- isa_intrsharetype_t type;
+ int type;
{
u_int8_t ocw1[2], elcr[2];
int icu, bit;
@@ -157,7 +156,7 @@ sio_setirqstat(irq, enabled, type)
/*
* interrupt type select: set bit to get level-triggered.
*/
- if (type == ISA_IST_LEVEL)
+ if (type == IST_LEVEL)
elcr[icu] |= 1 << bit;
else
elcr[icu] &= ~(1 << bit);
@@ -235,7 +234,7 @@ sio_intr_setup(ipf, ipfa)
*/
if (INITIALLY_LEVEL_TRIGGERED(i))
printf("sio_intr_setup: %d LT!\n", i);
- sio_setirqstat(i, INITIALLY_ENABLED(i), ISA_IST_EDGE);
+ sio_setirqstat(i, INITIALLY_ENABLED(i), IST_EDGE);
break;
case 2:
@@ -247,7 +246,7 @@ sio_intr_setup(ipf, ipfa)
printf("sio_intr_setup: %d LT!\n", i);
if (!INITIALLY_ENABLED(i))
printf("sio_intr_setup: %d not enabled!\n", i);
- sio_setirqstat(i, 1, ISA_IST_EDGE);
+ sio_setirqstat(i, 1, IST_EDGE);
break;
default:
@@ -256,8 +255,8 @@ sio_intr_setup(ipf, ipfa)
* type to (effectively) "unknown."
*/
sio_setirqstat(i, INITIALLY_ENABLED(i),
- INITIALLY_LEVEL_TRIGGERED(i) ? ISA_IST_LEVEL :
- ISA_IST_NONE);
+ INITIALLY_LEVEL_TRIGGERED(i) ? IST_LEVEL :
+ IST_NONE);
break;
}
}
@@ -267,8 +266,8 @@ void *
sio_intr_establish(siifa, irq, type, level, ih_fun, ih_arg)
void *siifa;
isa_irq_t irq;
- isa_intrsharetype_t type;
- isa_intrlevel_t level;
+ int type;
+ int level;
int (*ih_fun)(void *);
void *ih_arg;
{
@@ -280,16 +279,16 @@ sio_intr_establish(siifa, irq, type, level, ih_fun, ih_arg)
if (ih == NULL)
panic("sio_intr_establish: can't malloc handler info");
- if (irq > ICU_LEN || type == ISA_IST_NONE)
+ if (irq > ICU_LEN || type == IST_NONE)
panic("sio_intr_establish: bogus irq or type");
switch (sio_intrsharetype[irq]) {
- case ISA_IST_EDGE:
- case ISA_IST_LEVEL:
+ case IST_EDGE:
+ case IST_LEVEL:
if (type == sio_intrsharetype[irq])
break;
- case ISA_IST_PULSE:
- if (type != ISA_IST_NONE)
+ case IST_PULSE:
+ if (type != IST_NONE)
panic("intr_establish: can't share %s with %s",
isa_intrsharetype_name(sio_intrsharetype[irq]),
isa_intrsharetype_name(type));
diff --git a/sys/arch/amiga/dev/if_ae.c b/sys/arch/amiga/dev/if_ae.c
index 42cd6b5866f..c0d43f8e8a4 100644
--- a/sys/arch/amiga/dev/if_ae.c
+++ b/sys/arch/amiga/dev/if_ae.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ae.c,v 1.3 1995/10/07 18:12:42 chopps Exp $ */
+/* $NetBSD: if_ae.c,v 1.4 1995/12/24 02:29:52 mycroft Exp $ */
/*
* Copyright (c) 1995 Bernd Ernesti and Klaus Burkert. All rights reserved.
@@ -338,7 +338,7 @@ aereset(sc)
{
int s;
- s = splimp();
+ s = splnet();
aeinit(sc);
splx(s);
}
@@ -958,7 +958,7 @@ aeioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
diff --git a/sys/arch/amiga/dev/if_es.c b/sys/arch/amiga/dev/if_es.c
index 448573133eb..a7ce3b227a8 100644
--- a/sys/arch/amiga/dev/if_es.c
+++ b/sys/arch/amiga/dev/if_es.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_es.c,v 1.7 1995/08/18 15:27:57 chopps Exp $ */
+/* $NetBSD: if_es.c,v 1.8 1995/12/24 02:29:59 mycroft Exp $ */
/*
* Copyright (c) 1995 Michael L. Hitch
@@ -257,7 +257,7 @@ esinit(sc)
union smcregs *smc = sc->sc_base;
int s;
- s = splimp();
+ s = splnet();
#ifdef ESDEBUG
if (ifp->if_flags & IFF_RUNNING)
@@ -305,7 +305,7 @@ esintr(sc)
int i;
u_short intsts, intact;
union smcregs *smc;
- int s = splimp();
+ int s = splnet();
smc = sc->sc_base;
#ifdef ESDEBUG
@@ -934,7 +934,7 @@ esioctl(ifp, command, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (command) {
@@ -1035,7 +1035,7 @@ esreset(sc)
{
int s;
- s = splimp();
+ s = splnet();
esstop(sc);
esinit(sc);
splx(s);
diff --git a/sys/arch/amiga/dev/if_qn.c b/sys/arch/amiga/dev/if_qn.c
index e5f85f168b9..4a046032627 100644
--- a/sys/arch/amiga/dev/if_qn.c
+++ b/sys/arch/amiga/dev/if_qn.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_qn.c,v 1.2 1995/11/30 00:57:02 jtc Exp $ */
+/* $NetBSD: if_qn.c,v 1.3 1995/12/24 02:30:02 mycroft Exp $ */
/*
* Copyright (c) 1995 Mika Kortelainen
@@ -358,7 +358,7 @@ qnreset(sc)
{
int s;
- s = splimp();
+ s = splnet();
qnstop(sc);
qninit(sc);
splx(s);
@@ -866,7 +866,7 @@ qnioctl(ifp, command, data)
#endif
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (command) {
diff --git a/sys/arch/i386/isa/clock.c b/sys/arch/i386/isa/clock.c
index ff2f768d41c..31fed397d1c 100644
--- a/sys/arch/i386/isa/clock.c
+++ b/sys/arch/i386/isa/clock.c
@@ -1,4 +1,4 @@
-/* $NetBSD: clock.c,v 1.34 1995/08/13 04:06:29 mycroft Exp $ */
+/* $NetBSD: clock.c,v 1.35 1995/12/24 02:30:07 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -311,8 +311,7 @@ cpu_initclocks()
* XXX If you're doing strange things with multiple clocks, you might
* want to keep track of clock handlers.
*/
- (void)isa_intr_establish(0, ISA_IST_PULSE, ISA_IPL_CLOCK,
- clockintr, 0);
+ (void)isa_intr_establish(0, IST_PULSE, IPL_CLOCK, clockintr, 0);
}
void
diff --git a/sys/arch/i386/isa/fd.c b/sys/arch/i386/isa/fd.c
index 5a46d1b3147..5a48b6e8eb8 100644
--- a/sys/arch/i386/isa/fd.c
+++ b/sys/arch/i386/isa/fd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: fd.c,v 1.79 1995/08/21 06:56:14 mycroft Exp $ */
+/* $NetBSD: fd.c,v 1.80 1995/12/24 02:30:11 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum.
@@ -305,8 +305,8 @@ fdcattach(parent, self, aux)
at_setup_dmachan(fdc->sc_drq, FDC_MAXIOSIZE);
isa_establish(&fdc->sc_id, &fdc->sc_dev);
#endif
- fdc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- fdcintr, fdc);
+ fdc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, fdcintr,
+ fdc);
/*
* The NVRAM info only tells us about the first two disks on the
diff --git a/sys/arch/i386/isa/isa_machdep.c b/sys/arch/i386/isa/isa_machdep.c
index 5b7da9965be..b609f662c95 100644
--- a/sys/arch/i386/isa/isa_machdep.c
+++ b/sys/arch/i386/isa/isa_machdep.c
@@ -1,4 +1,4 @@
-/* $NetBSD: isa_machdep.c,v 1.8 1995/10/09 06:34:47 mycroft Exp $ */
+/* $NetBSD: isa_machdep.c,v 1.9 1995/12/24 02:30:15 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -239,6 +239,8 @@ fakeintr(arg)
return 0;
}
+#define LEGAL_IRQ(x) ((x) >= 0 && (x) < ICU_LEN && (x) != 2)
+
/*
* Set up an interrupt handler to start being called.
* XXX PRONE TO RACE CONDITIONS, UGLY, 'INTERESTING' INSERTION ALGORITHM.
@@ -246,12 +248,11 @@ fakeintr(arg)
void *
isa_intr_establish(irq, type, level, ih_fun, ih_arg)
int irq;
- isa_intrtype type;
- isa_intrlevel level;
+ int type;
+ int level;
int (*ih_fun) __P((void *));
void *ih_arg;
{
- int mask;
struct intrhand **p, *q, *ih;
static struct intrhand fakehand = {fakeintr};
extern int cold;
@@ -261,20 +262,16 @@ isa_intr_establish(irq, type, level, ih_fun, ih_arg)
if (ih == NULL)
panic("isa_intr_establish: can't malloc handler info");
- mask = 1 << irq;
-
- if (irq < 0 || irq > ICU_LEN || type == ISA_IST_NONE)
+ if (!LEGAL_IRQ(irq) || type == IST_NONE)
panic("intr_establish: bogus irq or type");
- if (fastvec & mask)
- panic("intr_establish: irq is already fast vector");
switch (intrtype[irq]) {
- case ISA_IST_EDGE:
- case ISA_IST_LEVEL:
+ case IST_EDGE:
+ case IST_LEVEL:
if (type == intrtype[irq])
break;
- case ISA_IST_PULSE:
- if (type != ISA_IST_NONE)
+ case IST_PULSE:
+ if (type != IST_NONE)
panic("intr_establish: can't share %s with %s",
isa_intr_typename(intrtype[irq]),
isa_intr_typename(type));
@@ -294,30 +291,7 @@ isa_intr_establish(irq, type, level, ih_fun, ih_arg)
* this with interrupts enabled and don't want the real routine called
* until masking is set up.
*/
- switch (level) {
- case ISA_IPL_NONE:
- fakehand.ih_level = IPL_NONE;
- break;
-
- case ISA_IPL_BIO:
- fakehand.ih_level = IPL_BIO;
- break;
-
- case ISA_IPL_NET:
- fakehand.ih_level = IPL_NET;
- break;
-
- case ISA_IPL_TTY:
- fakehand.ih_level = IPL_TTY;
- break;
-
- case ISA_IPL_CLOCK:
- fakehand.ih_level = IPL_CLOCK;
- break;
-
- default:
- panic("isa_intr_establish: bad interrupt level %d", level);
- }
+ fakehand.ih_level = level;
*p = &fakehand;
intr_calculatemasks();
@@ -329,7 +303,7 @@ isa_intr_establish(irq, type, level, ih_fun, ih_arg)
ih->ih_arg = ih_arg;
ih->ih_count = 0;
ih->ih_next = NULL;
- ih->ih_level = fakehand.ih_level;
+ ih->ih_level = level;
ih->ih_irq = irq;
*p = ih;
@@ -344,16 +318,11 @@ isa_intr_disestablish(arg)
void *arg;
{
struct intrhand *ih = arg;
- int irq, mask;
+ int irq = ih->ih_irq;
struct intrhand **p, *q;
- irq = ih->ih_irq;
- mask = 1 << irq;
-
- if (irq < 0 || irq > ICU_LEN)
+ if (!LEGAL_IRQ(irq))
panic("intr_disestablish: bogus irq");
- if (fastvec & mask)
- fastvec &= ~mask;
/*
* Remove the handler from the chain.
@@ -370,5 +339,5 @@ isa_intr_disestablish(arg)
intr_calculatemasks();
if (intrhand[irq] == NULL)
- intrtype[irq] = ISA_IST_NONE;
+ intrtype[irq] = IST_NONE;
}
diff --git a/sys/arch/i386/isa/lms.c b/sys/arch/i386/isa/lms.c
index 2d79f0d6984..7c453919051 100644
--- a/sys/arch/i386/isa/lms.c
+++ b/sys/arch/i386/isa/lms.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lms.c,v 1.20 1995/10/05 22:06:47 mycroft Exp $ */
+/* $NetBSD: lms.c,v 1.21 1995/12/24 02:30:17 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -119,8 +119,8 @@ lmsattach(parent, self, aux)
sc->sc_iobase = iobase;
sc->sc_state = 0;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_PULSE, ISA_IPL_TTY,
- lmsintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_PULSE, IPL_TTY, lmsintr,
+ sc);
}
int
diff --git a/sys/arch/i386/isa/mms.c b/sys/arch/i386/isa/mms.c
index 9081d199a82..ae4f144e726 100644
--- a/sys/arch/i386/isa/mms.c
+++ b/sys/arch/i386/isa/mms.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mms.c,v 1.19 1995/10/05 22:06:51 mycroft Exp $ */
+/* $NetBSD: mms.c,v 1.20 1995/12/24 02:30:19 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -109,8 +109,8 @@ mmsattach(parent, self, aux)
sc->sc_iobase = iobase;
sc->sc_state = 0;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_PULSE, ISA_IPL_TTY,
- mmsintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_PULSE, IPL_TTY, mmsintr,
+ sc);
}
int
diff --git a/sys/arch/i386/isa/npx.c b/sys/arch/i386/isa/npx.c
index ab6f116b8bd..bef94b488f0 100644
--- a/sys/arch/i386/isa/npx.c
+++ b/sys/arch/i386/isa/npx.c
@@ -1,4 +1,4 @@
-/* $NetBSD: npx.c,v 1.51 1995/10/10 04:46:09 mycroft Exp $ */
+/* $NetBSD: npx.c,v 1.52 1995/12/24 02:30:21 mycroft Exp $ */
#if 0
#define iprintf(x) printf x
@@ -325,8 +325,8 @@ npxattach(parent, self, aux)
case NPX_INTERRUPT:
printf("\n");
lcr0(rcr0() & ~CR0_NE);
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NONE, npxintr, 0);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NONE,
+ npxintr, 0);
break;
case NPX_EXCEPTION:
printf(": using exception 16\n");
diff --git a/sys/arch/i386/isa/pccons.c b/sys/arch/i386/isa/pccons.c
index 7ffe1503080..fefe23887d3 100644
--- a/sys/arch/i386/isa/pccons.c
+++ b/sys/arch/i386/isa/pccons.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pccons.c,v 1.90 1995/10/11 04:20:33 mycroft Exp $ */
+/* $NetBSD: pccons.c,v 1.91 1995/12/24 02:30:25 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum. All rights reserved.
@@ -470,8 +470,8 @@ pcattach(parent, self, aux)
printf(": %s\n", vs.color ? "color" : "mono");
do_async_update(1);
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- pcintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, pcintr,
+ sc);
}
int
diff --git a/sys/arch/i386/isa/pcvt/pcvt_drv.c b/sys/arch/i386/isa/pcvt/pcvt_drv.c
index d6aa3e27d81..220b4465b3a 100644
--- a/sys/arch/i386/isa/pcvt/pcvt_drv.c
+++ b/sys/arch/i386/isa/pcvt/pcvt_drv.c
@@ -335,8 +335,8 @@ pcattach(struct isa_device *dev)
#if PCVT_NETBSD > 9
#if PCVT_NETBSD > 101
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- pcintr, (void *)0);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, pcintr,
+ (void *)0);
#else /* PCVT_NETBSD > 100 */
vthand.ih_fun = pcrint;
vthand.ih_arg = 0;
diff --git a/sys/arch/i386/isa/pms.c b/sys/arch/i386/isa/pms.c
index 8098b473968..882b1a7951b 100644
--- a/sys/arch/i386/isa/pms.c
+++ b/sys/arch/i386/isa/pms.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pms.c,v 1.23 1995/10/05 22:06:54 mycroft Exp $ */
+/* $NetBSD: pms.c,v 1.24 1995/12/24 02:30:28 mycroft Exp $ */
/*-
* Copyright (c) 1994 Charles Hannum.
@@ -192,8 +192,8 @@ pmsattach(parent, self, aux)
/* Other initialization was done by pmsprobe. */
sc->sc_state = 0;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- pmsintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, pmsintr,
+ sc);
}
int
diff --git a/sys/arch/i386/pci/pci_machdep.c b/sys/arch/i386/pci/pci_machdep.c
index 788772b67d4..404fe2e1c54 100644
--- a/sys/arch/i386/pci/pci_machdep.c
+++ b/sys/arch/i386/pci/pci_machdep.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pci_machdep.c,v 1.17 1995/07/27 21:39:59 cgd Exp $ */
+/* $NetBSD: pci_machdep.c,v 1.18 1995/12/24 02:30:34 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -60,8 +60,6 @@
int pci_mode = -1;
-static isa_intrlevel pcilevel_to_isa __P((pci_intrlevel level));
-
int pcimatch __P((struct device *, void *, void *));
void pciattach __P((struct device *, struct device *, void *));
@@ -377,7 +375,7 @@ pci_map_mem(tag, reg, vap, pap)
void *
pci_map_int(tag, level, func, arg)
pcitag_t tag;
- pci_intrlevel level;
+ int level;
int (*func) __P((void *));
void *arg;
{
@@ -431,32 +429,5 @@ pci_map_int(tag, level, func, arg)
printf("pci_map_int: pin %c mapped to line %d\n", '@' + pin, line);
#endif
- return isa_intr_establish(line, ISA_IST_LEVEL, pcilevel_to_isa(level),
- func, arg);
-}
-
-static isa_intrlevel
-pcilevel_to_isa(level)
- pci_intrlevel level;
-{
-
- switch (level) {
- case PCI_IPL_NONE:
- return (ISA_IPL_NONE);
-
- case PCI_IPL_BIO:
- return (ISA_IPL_BIO);
-
- case PCI_IPL_NET:
- return (ISA_IPL_NET);
-
- case PCI_IPL_TTY:
- return (ISA_IPL_TTY);
-
- case PCI_IPL_CLOCK:
- return (ISA_IPL_CLOCK);
-
- default:
- panic("pcilevel_to_isa: unknown level %d\n", level);
- }
+ return isa_intr_establish(line, IST_LEVEL, level, func, arg);
}
diff --git a/sys/arch/pmax/dev/if_le.c b/sys/arch/pmax/dev/if_le.c
index 74b080804a7..3b0b7f86cb5 100644
--- a/sys/arch/pmax/dev/if_le.c
+++ b/sys/arch/pmax/dev/if_le.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_le.c,v 1.16 1995/08/13 00:07:17 mycroft Exp $ */
+/* $NetBSD: if_le.c,v 1.17 1995/12/24 02:30:42 mycroft Exp $ */
/*-
* Copyright (c) 1992, 1993
@@ -528,7 +528,7 @@ leinit(unit)
int s;
if ((ifp->if_flags & IFF_RUNNING) == 0) {
- s = splimp();
+ s = splnet();
ifp->if_flags |= IFF_RUNNING;
lereset(unit);
lestart(ifp);
@@ -968,7 +968,7 @@ leioctl(ifp, cmd, data)
volatile struct lereg1 *ler1 = le->sc_r1;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
case SIOCSIFADDR:
diff --git a/sys/arch/vax/if/if_de.c b/sys/arch/vax/if/if_de.c
index d42a45ec242..cf239587ca3 100644
--- a/sys/arch/vax/if/if_de.c
+++ b/sys/arch/vax/if/if_de.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_de.c,v 1.10 1995/12/01 19:37:55 ragge Exp $ */
+/* $NetBSD: if_de.c,v 1.11 1995/12/24 02:30:52 mycroft Exp $ */
/*
* Copyright (c) 1982, 1986, 1989 Regents of the University of California.
@@ -345,7 +345,7 @@ deinit(unit)
}
/* start up the board (rah rah) */
- s = splimp();
+ s = splnet();
ds->ds_rindex = ds->ds_xindex = ds->ds_xfree = ds->ds_nxmit = 0;
ds->ds_if.if_flags |= IFF_RUNNING;
addr->pclow = PCSR0_INTE; /* avoid interlock */
@@ -584,7 +584,7 @@ deioctl(ifp, cmd, data)
{
register struct ifaddr *ifa = (struct ifaddr *)data;
register struct de_softc *ds = decd.cd_devs[ifp->if_unit];
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
diff --git a/sys/arch/vax/if/if_qe.c b/sys/arch/vax/if/if_qe.c
index a468d3011f4..8f44ae74658 100644
--- a/sys/arch/vax/if/if_qe.c
+++ b/sys/arch/vax/if/if_qe.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_qe.c,v 1.7 1995/12/01 19:37:59 ragge Exp $ */
+/* $NetBSD: if_qe.c,v 1.8 1995/12/24 02:30:55 mycroft Exp $ */
/*
* Copyright (c) 1988 Regents of the University of California.
@@ -495,7 +495,7 @@ qeinit(unit)
* Take the interface out of reset, program the vector,
* enable interrupts, and tell the world we are up.
*/
- s = splimp();
+ s = splnet();
addr->qe_vector = sc->qe_intvec;
sc->addr = addr;
addr->qe_csr = QE_RCV_ENABLE | QE_INT_ENABLE | QE_XMIT_INT |
@@ -527,7 +527,7 @@ qestart(ifp)
int buf_addr, len, s;
- s = splimp();
+ s = splnet();
/*
* The deqna doesn't look at anything but the valid bit
* to determine if it should transmit this packet. If you have
@@ -773,7 +773,7 @@ qeioctl(ifp, cmd, data)
{
struct qe_softc *sc = qecd.cd_devs[ifp->if_unit];
struct ifaddr *ifa = (struct ifaddr *)data;
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
diff --git a/sys/dev/ata/wd.c b/sys/dev/ata/wd.c
index 90b6f37f56f..bcc4a55d4d9 100644
--- a/sys/dev/ata/wd.c
+++ b/sys/dev/ata/wd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: wd.c,v 1.142 1995/08/05 23:50:23 mycroft Exp $ */
+/* $NetBSD: wd.c,v 1.143 1995/12/24 02:31:59 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Charles M. Hannum. All rights reserved.
@@ -249,8 +249,8 @@ wdcattach(parent, self, aux)
printf("\n");
- wdc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- wdcintr, wdc);
+ wdc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, wdcintr,
+ wdc);
for (wa.wa_drive = 0; wa.wa_drive < 2; wa.wa_drive++)
(void)config_found(self, (void *)&wa, wdprint);
diff --git a/sys/dev/audio_if.h b/sys/dev/audio_if.h
index 362df226a51..5dd39a47db2 100644
--- a/sys/dev/audio_if.h
+++ b/sys/dev/audio_if.h
@@ -1,4 +1,4 @@
-/* $NetBSD: audio_if.h,v 1.5 1995/07/19 19:58:23 brezak Exp $ */
+/* $NetBSD: audio_if.h,v 1.6 1995/12/24 02:30:58 mycroft Exp $ */
/*
* Copyright (c) 1994 Havard Eidnes.
@@ -132,4 +132,4 @@ extern int audio_hardware_detach __P((struct audio_hw_if *));
#define AUDIODEV(x) (minor(x)&0xf0)
#define splaudio splbio /* XXX */
-#define ISA_IPL_AUDIO ISA_IPL_BIO /* XXX */
+#define IPL_AUDIO IPL_BIO /* XXX */
diff --git a/sys/dev/eisa/aha1742.c b/sys/dev/eisa/aha1742.c
index 0863293bb9b..88a3cc5c927 100644
--- a/sys/dev/eisa/aha1742.c
+++ b/sys/dev/eisa/aha1742.c
@@ -1,4 +1,4 @@
-/* $NetBSD: aha1742.c,v 1.52 1995/10/04 00:35:10 mycroft Exp $ */
+/* $NetBSD: aha1742.c,v 1.53 1995/12/24 02:31:01 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -539,8 +539,8 @@ ahbattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&ahb->sc_id, &ahb->sc_dev);
#endif
- ahb->sc_ih = eisa_intr_establish(ia->ia_irq, EISA_IST_LEVEL,
- EISA_IPL_BIO, ahbintr, ahb);
+ ahb->sc_ih = eisa_intr_establish(ia->ia_irq, IST_LEVEL, IPL_BIO,
+ ahbintr, ahb);
/*
* ask the adapter what subunits are present
diff --git a/sys/dev/eisa/eisavar.h b/sys/dev/eisa/eisavar.h
index 85cf6cb4294..6a2464876fa 100644
--- a/sys/dev/eisa/eisavar.h
+++ b/sys/dev/eisa/eisavar.h
@@ -1,4 +1,4 @@
-/* $NetBSD: eisavar.h,v 1.1 1995/04/17 12:08:23 cgd Exp $ */
+/* $NetBSD: eisavar.h,v 1.2 1995/12/24 02:31:02 mycroft Exp $ */
/*
* Copyright (c) 1995 Christopher G. Demetriou
@@ -51,13 +51,3 @@
#define eisadev isadev /* XXX */
#define eisa_intr_establish isa_intr_establish /* XXX */
#define eisa_intr_disestablish isa_intr_disestablish /* XXX */
-
-#define EISA_IPL_NONE ISA_IPL_NONE /* XXX */
-#define EISA_IPL_BIO ISA_IPL_BIO /* XXX */
-#define EISA_IPL_NET ISA_IPL_NET /* XXX */
-#define EISA_IPL_TTY ISA_IPL_TTY /* XXX */
-#define EISA_IPL_CLOCK ISA_IPL_CLOCK /* XXX */
-
-#define EISA_IST_PULSE ISA_IST_PULSE /* XXX */
-#define EISA_IST_EDGE ISA_IST_EDGE /* XXX */
-#define EISA_IST_LEVEL ISA_IST_LEVEL /* XXX */
diff --git a/sys/dev/ic/aic6360.c b/sys/dev/ic/aic6360.c
index 7a910b20a46..974f46693c1 100644
--- a/sys/dev/ic/aic6360.c
+++ b/sys/dev/ic/aic6360.c
@@ -1,4 +1,4 @@
-/* $NetBSD: aic6360.c,v 1.37 1995/11/30 00:59:51 jtc Exp $ */
+/* $NetBSD: aic6360.c,v 1.38 1995/12/24 02:31:08 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Charles Hannum. All rights reserved.
@@ -766,8 +766,8 @@ aicattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&sc->sc_id, &sc->sc_dev);
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- aicintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, aicintr,
+ sc);
config_found(self, &sc->sc_link, aicprint);
}
diff --git a/sys/dev/ic/com.c b/sys/dev/ic/com.c
index 52b8dfc06fb..4697f963c4b 100644
--- a/sys/dev/ic/com.c
+++ b/sys/dev/ic/com.c
@@ -1,4 +1,4 @@
-/* $NetBSD: com.c,v 1.62 1995/10/15 19:43:04 mycroft Exp $ */
+/* $NetBSD: com.c,v 1.63 1995/12/24 02:31:15 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles M. Hannum. All rights reserved.
@@ -223,8 +223,8 @@ comattach(parent, self, aux)
outb(iobase + com_mcr, 0);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_TTY, comintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY,
+ comintr, sc);
#ifdef KGDB
if (kgdb_dev == makedev(commajor, unit)) {
diff --git a/sys/dev/ic/lpt.c b/sys/dev/ic/lpt.c
index aee3a5be153..959a3a9dddd 100644
--- a/sys/dev/ic/lpt.c
+++ b/sys/dev/ic/lpt.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lpt.c,v 1.30 1995/04/17 12:09:17 cgd Exp $ */
+/* $NetBSD: lpt.c,v 1.31 1995/12/24 02:31:40 mycroft Exp $ */
/*
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -238,8 +238,8 @@ lptattach(parent, self, aux)
outb(iobase + lpt_control, LPC_NINIT);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NONE, lptintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NONE,
+ lptintr, sc);
}
/*
diff --git a/sys/dev/ic/lptvar.h b/sys/dev/ic/lptvar.h
index 87ee438dfec..3087a16dabb 100644
--- a/sys/dev/ic/lptvar.h
+++ b/sys/dev/ic/lptvar.h
@@ -1,4 +1,4 @@
-/* $NetBSD: lptvar.h,v 1.30 1995/04/17 12:09:17 cgd Exp $ */
+/* $NetBSD: lptvar.h,v 1.31 1995/12/24 02:31:40 mycroft Exp $ */
/*
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -238,8 +238,8 @@ lptattach(parent, self, aux)
outb(iobase + lpt_control, LPC_NINIT);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NONE, lptintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NONE,
+ lptintr, sc);
}
/*
diff --git a/sys/dev/isa/aha1542.c b/sys/dev/isa/aha1542.c
index 6a94546f4f1..bc50dc5f689 100644
--- a/sys/dev/isa/aha1542.c
+++ b/sys/dev/isa/aha1542.c
@@ -1,4 +1,4 @@
-/* $NetBSD: aha1542.c,v 1.54 1995/11/10 04:41:58 mycroft Exp $ */
+/* $NetBSD: aha1542.c,v 1.55 1995/12/24 02:31:06 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -585,8 +585,8 @@ ahaattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&aha->sc_id, &aha->sc_dev);
#endif
- aha->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- ahaintr, aha);
+ aha->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, ahaintr,
+ aha);
/*
* ask the adapter what subunits are present
diff --git a/sys/dev/isa/aic6360.c b/sys/dev/isa/aic6360.c
index 7a910b20a46..974f46693c1 100644
--- a/sys/dev/isa/aic6360.c
+++ b/sys/dev/isa/aic6360.c
@@ -1,4 +1,4 @@
-/* $NetBSD: aic6360.c,v 1.37 1995/11/30 00:59:51 jtc Exp $ */
+/* $NetBSD: aic6360.c,v 1.38 1995/12/24 02:31:08 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Charles Hannum. All rights reserved.
@@ -766,8 +766,8 @@ aicattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&sc->sc_id, &sc->sc_dev);
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- aicintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, aicintr,
+ sc);
config_found(self, &sc->sc_link, aicprint);
}
diff --git a/sys/dev/isa/ast.c b/sys/dev/isa/ast.c
index 77abde08861..e18ba1abb7d 100644
--- a/sys/dev/isa/ast.c
+++ b/sys/dev/isa/ast.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ast.c,v 1.18 1995/06/26 04:08:04 cgd Exp $ */
+/* $NetBSD: ast.c,v 1.19 1995/12/24 02:31:10 mycroft Exp $ */
/*
* Copyright (c) 1995 Charles Hannum. All rights reserved.
@@ -139,8 +139,8 @@ astattach(parent, self, aux)
}
}
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- astintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, astintr,
+ sc);
}
int
diff --git a/sys/dev/isa/boca.c b/sys/dev/isa/boca.c
index 796fe0d3771..a17496ed74a 100644
--- a/sys/dev/isa/boca.c
+++ b/sys/dev/isa/boca.c
@@ -1,4 +1,4 @@
-/* $NetBSD: boca.c,v 1.5 1995/06/26 04:08:06 cgd Exp $ */
+/* $NetBSD: boca.c,v 1.6 1995/12/24 02:31:11 mycroft Exp $ */
/*
* Copyright (c) 1995 Charles Hannum. All rights reserved.
@@ -134,8 +134,8 @@ bocaattach(parent, self, aux)
}
}
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- bocaintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, bocaintr,
+ sc);
}
int
diff --git a/sys/dev/isa/bt742a.c b/sys/dev/isa/bt742a.c
index e179c176066..1ae39c5055f 100644
--- a/sys/dev/isa/bt742a.c
+++ b/sys/dev/isa/bt742a.c
@@ -1,4 +1,4 @@
-/* $NetBSD: bt742a.c,v 1.49 1995/10/03 20:58:58 mycroft Exp $ */
+/* $NetBSD: bt742a.c,v 1.50 1995/12/24 02:31:13 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -612,8 +612,8 @@ btattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&bt->sc_id, &bt->sc_dev);
#endif
- bt->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- btintr, bt);
+ bt->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, btintr,
+ bt);
/*
* ask the adapter what subunits are present
diff --git a/sys/dev/isa/com.c b/sys/dev/isa/com.c
index 52b8dfc06fb..4697f963c4b 100644
--- a/sys/dev/isa/com.c
+++ b/sys/dev/isa/com.c
@@ -1,4 +1,4 @@
-/* $NetBSD: com.c,v 1.62 1995/10/15 19:43:04 mycroft Exp $ */
+/* $NetBSD: com.c,v 1.63 1995/12/24 02:31:15 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles M. Hannum. All rights reserved.
@@ -223,8 +223,8 @@ comattach(parent, self, aux)
outb(iobase + com_mcr, 0);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_TTY, comintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY,
+ comintr, sc);
#ifdef KGDB
if (kgdb_dev == makedev(commajor, unit)) {
diff --git a/sys/dev/isa/gus.c b/sys/dev/isa/gus.c
index 7f1c415f434..416048a8acd 100644
--- a/sys/dev/isa/gus.c
+++ b/sys/dev/isa/gus.c
@@ -1,4 +1,4 @@
-/* $NetBSD: gus.c,v 1.3 1995/11/10 04:30:44 mycroft Exp $ */
+/* $NetBSD: gus.c,v 1.4 1995/12/24 02:31:17 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Ken Hornstein. All rights reserved.
@@ -911,10 +911,10 @@ gusattach(parent, self, aux)
*/
/* XXX we shouldn't have to use splgus == splclock, nor should
- * we use ISA_IPL_CLOCK.
+ * we use IPL_CLOCK.
*/
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
- gusintr, sc /* sc->sc_gusdsp */);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_AUDIO, gusintr,
+ sc /* sc->sc_gusdsp */);
/*
* Set some default values
diff --git a/sys/dev/isa/if_eg.c b/sys/dev/isa/if_eg.c
index 4f2e8402a2e..7f5f91a4376 100644
--- a/sys/dev/isa/if_eg.c
+++ b/sys/dev/isa/if_eg.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_eg.c,v 1.20 1995/07/24 04:12:45 mycroft Exp $ */
+/* $NetBSD: if_eg.c,v 1.21 1995/12/24 02:31:24 mycroft Exp $ */
/*
* Copyright (c) 1993 Dean Huxley <dean@fsa.ca>
@@ -409,8 +409,8 @@ egattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- egintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, egintr,
+ sc);
}
void
@@ -731,7 +731,7 @@ egioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -813,7 +813,7 @@ egreset(sc)
int s;
dprintf(("egreset()\n"));
- s = splimp();
+ s = splnet();
egstop(sc);
eginit(sc);
splx(s);
diff --git a/sys/dev/isa/if_le.c b/sys/dev/isa/if_le.c
index eb0f039c22a..9be954505e2 100644
--- a/sys/dev/isa/if_le.c
+++ b/sys/dev/isa/if_le.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_le.c,v 1.37 1995/11/25 01:24:00 cgd Exp $ */
+/* $NetBSD: if_le.c,v 1.38 1995/12/24 02:31:35 mycroft Exp $ */
/*-
* Copyright (c) 1995 Charles M. Hannum. All rights reserved.
@@ -397,8 +397,8 @@ leattach(parent, self, aux)
if (ia->ia_drq != DRQUNK)
isa_dmacascade(ia->ia_drq);
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NET, leintredge, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET,
+ leintredge, sc);
}
#endif
@@ -410,7 +410,7 @@ leattach(parent, self, aux)
pci_conf_read(pa->pa_tag, PCI_COMMAND_STATUS_REG) |
PCI_COMMAND_MASTER_ENABLE);
- sc->sc_ih = pci_map_int(pa->pa_tag, PCI_IPL_NET, leintr, sc);
+ sc->sc_ih = pci_map_int(pa->pa_tag, IPL_NET, leintr, sc);
}
#endif
diff --git a/sys/dev/isa/isa.c b/sys/dev/isa/isa.c
index 799bf2fb2f9..9fdeb3af1f4 100644
--- a/sys/dev/isa/isa.c
+++ b/sys/dev/isa/isa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: isa.c,v 1.74 1995/06/07 06:46:04 cgd Exp $ */
+/* $NetBSD: isa.c,v 1.75 1995/12/24 02:31:37 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994 Charles Hannum. All rights reserved.
@@ -88,17 +88,17 @@ isascan(parent, match)
char *
isa_intr_typename(type)
- isa_intrtype type;
+ int type;
{
switch (type) {
- case ISA_IST_NONE :
+ case IST_NONE :
return ("none");
- case ISA_IST_PULSE:
+ case IST_PULSE:
return ("pulsed");
- case ISA_IST_EDGE:
+ case IST_EDGE:
return ("edge-triggered");
- case ISA_IST_LEVEL:
+ case IST_LEVEL:
return ("level-triggered");
default:
panic("isa_intr_typename: invalid type %d", type);
diff --git a/sys/dev/isa/isavar.h b/sys/dev/isa/isavar.h
index 96fc2455992..581288a6dc2 100644
--- a/sys/dev/isa/isavar.h
+++ b/sys/dev/isa/isavar.h
@@ -1,4 +1,4 @@
-/* $NetBSD: isavar.h,v 1.16 1995/06/07 06:45:44 cgd Exp $ */
+/* $NetBSD: isavar.h,v 1.17 1995/12/24 02:31:38 mycroft Exp $ */
/*
* Copyright (c) 1995 Chris G. Demetriou
@@ -102,27 +102,11 @@ struct isa_softc {
*/
/* ISA interrupt sharing types */
-typedef enum {
- ISA_IST_NONE = 0, /* not yet assigned */
- ISA_IST_PULSE, /* pulsed */
- ISA_IST_EDGE, /* edge-triggered */
- ISA_IST_LEVEL /* level-triggered */
-} isa_intrtype;
-
-/* ISA interrupt levels; system interrupt levels for ISA bus use */
-typedef enum {
- ISA_IPL_NONE, /* block only the interrupt's IRQ*/
- ISA_IPL_BIO, /* block I/O interrupts */
- ISA_IPL_NET, /* network */
- ISA_IPL_TTY, /* terminal */
- ISA_IPL_CLOCK, /* clock */
-} isa_intrlevel;
-
void isascan __P((struct device *parent, void *match));
-void *isa_intr_establish __P((int intr, isa_intrtype type,
- isa_intrlevel level, int (*ih_fun)(void *), void *ih_arg));
+void *isa_intr_establish __P((int intr, int type, int level,
+ int (*ih_fun)(void *), void *ih_arg));
void isa_intr_disestablish __P((void *handler));
-char *isa_intr_typename __P((isa_intrtype type));
+char *isa_intr_typename __P((int type));
#ifdef NEWCONFIG
/*
diff --git a/sys/dev/isa/lpt.c b/sys/dev/isa/lpt.c
index aee3a5be153..959a3a9dddd 100644
--- a/sys/dev/isa/lpt.c
+++ b/sys/dev/isa/lpt.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lpt.c,v 1.30 1995/04/17 12:09:17 cgd Exp $ */
+/* $NetBSD: lpt.c,v 1.31 1995/12/24 02:31:40 mycroft Exp $ */
/*
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -238,8 +238,8 @@ lptattach(parent, self, aux)
outb(iobase + lpt_control, LPC_NINIT);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NONE, lptintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NONE,
+ lptintr, sc);
}
/*
diff --git a/sys/dev/isa/lpt_isa.c b/sys/dev/isa/lpt_isa.c
index f0cfc85a43d..9575d1ac092 100644
--- a/sys/dev/isa/lpt_isa.c
+++ b/sys/dev/isa/lpt_isa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lpt_isa.c,v 1.30 1995/04/17 12:09:17 cgd Exp $ */
+/* $NetBSD: lpt_isa.c,v 1.31 1995/12/24 02:31:40 mycroft Exp $ */
/*
* Copyright (c) 1993, 1994 Charles Hannum.
@@ -238,8 +238,8 @@ lptattach(parent, self, aux)
outb(iobase + lpt_control, LPC_NINIT);
if (ia->ia_irq != IRQUNK)
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NONE, lptintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NONE,
+ lptintr, sc);
}
/*
diff --git a/sys/dev/isa/mcd.c b/sys/dev/isa/mcd.c
index 35941a8bfa1..6b6dd178772 100644
--- a/sys/dev/isa/mcd.c
+++ b/sys/dev/isa/mcd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mcd.c,v 1.42 1995/08/05 23:47:52 mycroft Exp $ */
+/* $NetBSD: mcd.c,v 1.43 1995/12/24 02:31:42 mycroft Exp $ */
/*
* Copyright (c) 1993, 1994, 1995 Charles M. Hannum. All rights reserved.
@@ -222,8 +222,8 @@ mcdattach(parent, self, aux)
sc->sc_dk.dk_driver = &mcddkdriver;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- mcdintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, mcdintr,
+ sc);
}
/*
diff --git a/sys/dev/isa/pas.c b/sys/dev/isa/pas.c
index 417b2325e5a..bbc6e548e52 100644
--- a/sys/dev/isa/pas.c
+++ b/sys/dev/isa/pas.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pas.c,v 1.10 1995/11/10 05:05:18 mycroft Exp $ */
+/* $NetBSD: pas.c,v 1.11 1995/12/24 02:31:43 mycroft Exp $ */
/*
* Copyright (c) 1991-1993 Regents of the University of California.
@@ -431,7 +431,7 @@ pasattach(parent, self, aux)
int err;
sc->sc_iobase = iobase;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_AUDIO,
sbdsp_intr, &sc->sc_sbdsp);
printf(" ProAudio Spectrum %s [rev %d] ", pasnames[sc->model], sc->rev);
diff --git a/sys/dev/isa/pss.c b/sys/dev/isa/pss.c
index a5b4f0d5876..e70f214295e 100644
--- a/sys/dev/isa/pss.c
+++ b/sys/dev/isa/pss.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pss.c,v 1.10 1995/11/10 04:30:49 mycroft Exp $ */
+/* $NetBSD: pss.c,v 1.11 1995/12/24 02:31:45 mycroft Exp $ */
/*
* Copyright (c) 1994 John Brezak
@@ -1004,8 +1004,8 @@ pssattach(parent, self, aux)
#endif
/* Setup interrupt handler for PSS */
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
- pssintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_AUDIO, pssintr,
+ sc);
vers = (inw(sc->sc_iobase+PSS_ID_VERS)&0xff) - 1;
printf(": ESC614%c\n", (vers > 0)?'A'+vers:' ');
@@ -1039,8 +1039,8 @@ spattach(parent, self, aux)
isa_establish(&sc->sc_id, &sc->sc_dev);
#endif
- sc->sc_ih = isa_intr_establish(cf->cf_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
- ad1848_intr, sc);
+ sc->sc_ih = isa_intr_establish(cf->cf_irq, IST_EDGE, IPL_AUDIO, ad1848_intr,
+ sc);
/* XXX might use pssprint func ?? */
printf(" port 0x%x-0x%x irq %d drq %d",
@@ -1067,8 +1067,8 @@ mpuattach(parent, self, aux)
isa_establish(&sc->sc_id, &sc->sc_dev);
#endif
- sc->sc_ih = isa_intr_establish(cf->cf_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
- mpuintr, sc);
+ sc->sc_ih = isa_intr_establish(cf->cf_irq, IST_EDGE, IPL_AUDIO, mpuintr,
+ sc);
/* XXX might use pssprint func ?? */
printf(" port 0x%x-0x%x irq %d\n",
diff --git a/sys/dev/isa/rtfps.c b/sys/dev/isa/rtfps.c
index cff8651d628..41cc056332a 100644
--- a/sys/dev/isa/rtfps.c
+++ b/sys/dev/isa/rtfps.c
@@ -1,4 +1,4 @@
-/* $NetBSD: rtfps.c,v 1.13 1995/06/26 04:12:01 cgd Exp $ */
+/* $NetBSD: rtfps.c,v 1.14 1995/12/24 02:31:48 mycroft Exp $ */
/*
* Copyright (c) 1995 Charles Hannum. All rights reserved.
@@ -147,8 +147,7 @@ rtfpsattach(parent, self, aux)
}
}
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_TTY,
- rtfpsintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_TTY, rtfpsintr, sc);
}
int
diff --git a/sys/dev/isa/sb.c b/sys/dev/isa/sb.c
index 43d4aab1c15..4fffcee54e4 100644
--- a/sys/dev/isa/sb.c
+++ b/sys/dev/isa/sb.c
@@ -1,4 +1,4 @@
-/* $NetBSD: sb.c,v 1.28 1995/11/10 05:01:05 mycroft Exp $ */
+/* $NetBSD: sb.c,v 1.29 1995/12/24 02:31:49 mycroft Exp $ */
/*
* Copyright (c) 1991-1993 Regents of the University of California.
@@ -273,7 +273,7 @@ sbattach(parent, self, aux)
register int iobase = ia->ia_iobase;
int err;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_AUDIO,
sbdsp_intr, sc);
sbdsp_attach(sc);
diff --git a/sys/dev/isa/seagate.c b/sys/dev/isa/seagate.c
index 2319e2ef55f..4e2ef8990cc 100644
--- a/sys/dev/isa/seagate.c
+++ b/sys/dev/isa/seagate.c
@@ -438,8 +438,8 @@ seaattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&sea->sc_id, &sea->sc_deV);
#endif
- sea->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- seaintr, sea);
+ sea->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, seaintr,
+ sea);
/*
* ask the adapter what subunits are present
diff --git a/sys/dev/isa/ultra14f.c b/sys/dev/isa/ultra14f.c
index ef81aba0e9a..87464eaba85 100644
--- a/sys/dev/isa/ultra14f.c
+++ b/sys/dev/isa/ultra14f.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ultra14f.c,v 1.58 1995/11/10 04:42:07 mycroft Exp $ */
+/* $NetBSD: ultra14f.c,v 1.59 1995/12/24 02:31:56 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -608,7 +608,7 @@ uhaattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&uha->sc_id, &uha->sc_dev);
#endif
- uha->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
+ uha->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO,
uha->intr, uha);
/*
diff --git a/sys/dev/isa/wd.c b/sys/dev/isa/wd.c
index 90b6f37f56f..bcc4a55d4d9 100644
--- a/sys/dev/isa/wd.c
+++ b/sys/dev/isa/wd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: wd.c,v 1.142 1995/08/05 23:50:23 mycroft Exp $ */
+/* $NetBSD: wd.c,v 1.143 1995/12/24 02:31:59 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Charles M. Hannum. All rights reserved.
@@ -249,8 +249,8 @@ wdcattach(parent, self, aux)
printf("\n");
- wdc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- wdcintr, wdc);
+ wdc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, wdcintr,
+ wdc);
for (wa.wa_drive = 0; wa.wa_drive < 2; wa.wa_drive++)
(void)config_found(self, (void *)&wa, wdprint);
diff --git a/sys/dev/isa/wss.c b/sys/dev/isa/wss.c
index 802fe505284..16a2499c548 100644
--- a/sys/dev/isa/wss.c
+++ b/sys/dev/isa/wss.c
@@ -1,4 +1,4 @@
-/* $NetBSD: wss.c,v 1.7 1995/11/10 04:30:52 mycroft Exp $ */
+/* $NetBSD: wss.c,v 1.8 1995/12/24 02:32:03 mycroft Exp $ */
/*
* Copyright (c) 1994 John Brezak
@@ -249,8 +249,7 @@ wssattach(parent, self, aux)
#ifdef NEWCONFIG
isa_establish(&sc->sc_id, &sc->sc_dev);
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_AUDIO,
- ad1848_intr, &sc->sc_ad1848);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_AUDIO, ad1848_intr, &sc->sc_ad1848);
ad1848_attach(&sc->sc_ad1848);
diff --git a/sys/dev/isa/wt.c b/sys/dev/isa/wt.c
index e770b00661e..d28b72f5ea0 100644
--- a/sys/dev/isa/wt.c
+++ b/sys/dev/isa/wt.c
@@ -1,4 +1,4 @@
-/* $NetBSD: wt.c,v 1.26 1995/07/04 07:23:58 mycroft Exp $ */
+/* $NetBSD: wt.c,v 1.27 1995/12/24 02:32:05 mycroft Exp $ */
/*
* Streamer tape driver.
@@ -249,8 +249,8 @@ wtattach(parent, self, aux)
sc->flags = TPSTART; /* tape is rewound */
sc->dens = -1; /* unknown density */
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_BIO,
- wtintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_BIO, wtintr,
+ sc);
}
int
diff --git a/sys/dev/pci/aic7870.c b/sys/dev/pci/aic7870.c
index 0206f33ff33..de4ce587b9e 100644
--- a/sys/dev/pci/aic7870.c
+++ b/sys/dev/pci/aic7870.c
@@ -19,7 +19,7 @@
* 4. Modifications may be freely made to this file if the above conditions
* are met.
*
- * $Id: aic7870.c,v 1.3 1995/11/12 20:55:26 christos Exp $
+ * $Id: aic7870.c,v 1.4 1995/12/24 02:32:09 mycroft Exp $
*/
#include <sys/param.h>
@@ -106,5 +106,5 @@ aic7870_attach(parent, self, aux)
ahcattach(ahc);
- ahc->sc_ih = pci_map_int(pa->pa_tag, PCI_IPL_BIO, ahcintr, ahc);
+ ahc->sc_ih = pci_map_int(pa->pa_tag, IPL_BIO, ahcintr, ahc);
}
diff --git a/sys/dev/pci/if_de.c b/sys/dev/pci/if_de.c
index 7875a6ecd97..57d4059775d 100644
--- a/sys/dev/pci/if_de.c
+++ b/sys/dev/pci/if_de.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_de.c,v 1.10 1995/12/23 06:22:46 tls Exp $ */
+/* $NetBSD: if_de.c,v 1.11 1995/12/24 02:32:13 mycroft Exp $ */
/*-
* Copyright (c) 1994, 1995 Matt Thomas (matt@lkg.dec.com)
@@ -1919,7 +1919,7 @@ tulip_ioctl(
struct ifreq *ifr = (struct ifreq *) data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
case SIOCSIFADDR: {
@@ -2569,7 +2569,7 @@ tulip_pci_attach(
bit longer anyways) */
#if defined(__NetBSD__)
if (sc->tulip_boardsw->bd_type != TULIP_DC21040_ZX314_SLAVE) {
- sc->tulip_ih = pci_map_int(pa->pa_tag, PCI_IPL_NET, tulip_intr, sc);
+ sc->tulip_ih = pci_map_int(pa->pa_tag, IPL_NET, tulip_intr, sc);
if (sc->tulip_ih == NULL) {
printf("%s%d: couldn't map interrupt\n",
sc->tulip_name, sc->tulip_unit);
diff --git a/sys/dev/pci/if_fpa.c b/sys/dev/pci/if_fpa.c
index ed19d4ee39b..979c30a9547 100644
--- a/sys/dev/pci/if_fpa.c
+++ b/sys/dev/pci/if_fpa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_fpa.c,v 1.2 1995/08/19 04:35:25 cgd Exp $ */
+/* $NetBSD: if_fpa.c,v 1.3 1995/12/24 02:32:17 mycroft Exp $ */
/*-
* Copyright (c) 1995 Matt Thomas (thomas@lkg.dec.com)
@@ -389,7 +389,7 @@ pdq_pci_attach(
bcopy((caddr_t) sc->sc_pdq->pdq_hwaddr.lanaddr_bytes, sc->sc_ac.ac_enaddr, 6);
pdq_ifattach(sc, pdq_pci_ifinit, pdq_pci_ifwatchdog);
- sc->sc_ih = pci_map_int(pa->pa_tag, PCI_IPL_NET, pdq_pci_ifintr, sc);
+ sc->sc_ih = pci_map_int(pa->pa_tag, IPL_NET, pdq_pci_ifintr, sc);
if (sc->sc_ih == NULL) {
printf("fpa%d: error: couldn't map interrupt\n", sc->sc_if.if_unit);
return;
diff --git a/sys/dev/pci/ncr.c b/sys/dev/pci/ncr.c
index de7bc637c1c..2a0515307fe 100644
--- a/sys/dev/pci/ncr.c
+++ b/sys/dev/pci/ncr.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ncr.c,v 1.21 1995/11/30 00:59:57 jtc Exp $ */
+/* $NetBSD: ncr.c,v 1.22 1995/12/24 02:32:24 mycroft Exp $ */
/**************************************************************************
**
@@ -1256,7 +1256,7 @@ static void ncr_attach (pcici_t tag, int unit);
static char ident[] =
- "\n$Id: ncr.c,v 1.21 1995/11/30 00:59:57 jtc Exp $\n";
+ "\n$Id: ncr.c,v 1.22 1995/12/24 02:32:24 mycroft Exp $\n";
u_long ncr_version = NCR_VERSION * 11
+ (u_long) sizeof (struct ncb) * 7
@@ -3262,7 +3262,7 @@ ncr_attach(parent, self, aux)
if (retval)
return;
- np->sc_ih = pci_map_int(pa->pa_tag, PCI_IPL_BIO, ncr_intr, np);
+ np->sc_ih = pci_map_int(pa->pa_tag, IPL_BIO, ncr_intr, np);
if (np->sc_ih == NULL)
return;
diff --git a/sys/dev/pci/pcivar.h b/sys/dev/pci/pcivar.h
index a552dd0f37e..047753501ef 100644
--- a/sys/dev/pci/pcivar.h
+++ b/sys/dev/pci/pcivar.h
@@ -1,4 +1,4 @@
-/* $NetBSD: pcivar.h,v 1.8 1995/06/18 01:26:50 cgd Exp $ */
+/* $NetBSD: pcivar.h,v 1.9 1995/12/24 02:32:31 mycroft Exp $ */
/*
* Copyright (c) 1994 Charles Hannum. All rights reserved.
@@ -49,15 +49,6 @@ ERROR: COMPILING FOR UNSUPPORTED MACHINE, OR MORE THAN ONE.
#include <i386/pci/pci_machdep.h>
#endif
-/* PCI interrupt levels; system interrupt levels for PCI bus use */
-typedef enum {
- PCI_IPL_NONE, /* block only the interrupt's IRQ*/
- PCI_IPL_BIO, /* block I/O interrupts */
- PCI_IPL_NET, /* network */
- PCI_IPL_TTY, /* terminal */
- PCI_IPL_CLOCK, /* clock */
-} pci_intrlevel;
-
struct pci_attach_args {
int pa_bus;
int pa_device;
@@ -69,7 +60,7 @@ pcireg_t pci_conf_read __P((pcitag_t, int));
void pci_conf_write __P((pcitag_t, int, pcireg_t));
void pci_devinfo __P((pcireg_t, pcireg_t, char *, int *));
pcitag_t pci_make_tag __P((int, int, int));
-void *pci_map_int __P((pcitag_t, pci_intrlevel, int (*)(void *), void *));
+void *pci_map_int __P((pcitag_t, int, int (*)(void *), void *));
int pci_map_mem __P((pcitag_t, int, vm_offset_t *, vm_offset_t *));
int pci_attach_subdev __P((struct device *, int, int));
diff --git a/sys/arch/amiga/dev/if_bah.c b/sys/arch/amiga/dev/if_bah.c
index 13065835d53..58fff79d236 100644
--- a/sys/arch/amiga/dev/if_bah.c
+++ b/sys/arch/amiga/dev/if_bah.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_bah.c,v 1.12 1995/10/09 15:20:25 chopps Exp $ */
+/* $NetBSD: if_bah.c,v 1.13 1995/12/24 02:29:55 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Ignatios Souvatzis
@@ -309,7 +309,7 @@ bah_init(sc)
ifp = &sc->sc_arccom.ac_if;
if ((ifp->if_flags & IFF_RUNNING) == 0) {
- s = splimp();
+ s = splnet();
ifp->if_flags |= IFF_RUNNING;
bah_reset(sc);
bah_start(ifp);
@@ -548,7 +548,7 @@ bah_start(ifp)
if ((ifp->if_flags & IFF_RUNNING) == 0)
return;
- s = splimp();
+ s = splnet();
if (sc->sc_tx_fillcount >= 2) {
splx(s);
@@ -643,7 +643,7 @@ bah_start(ifp)
sc->sc_retransmits[buffer] = (m->m_flags & M_BCAST) ? 1 : 5;
/* actually transmit the packet */
- s = splimp();
+ s = splnet();
if (++sc->sc_tx_fillcount > 1) {
/*
@@ -780,7 +780,7 @@ bah_srint(sc, dummy)
head = 0;
ifp = &sc->sc_arccom.ac_if;
- s = splimp();
+ s = splnet();
if (sc->sc_rx_fillcount <= 1)
buffer = sc->sc_rx_act ^ 1;
else {
@@ -909,7 +909,7 @@ cleanup:
if (head == NULL)
m_freem(head);
- s = splimp();
+ s = splnet();
if (--sc->sc_rx_fillcount == 1) {
@@ -1152,7 +1152,7 @@ bah_ioctl(ifp, command, data)
error = 0;
sc = bahcd.cd_devs[ifp->if_unit];
ifa = (struct ifaddr *)data;
- s = splimp();
+ s = splnet();
#if defined(BAH_DEBUG) && (BAH_DEBUG > 2)
printf("%s: ioctl() called, cmd = 0x%x\n",
@@ -1215,7 +1215,7 @@ bah_ioctl(ifp, command, data)
* and the int handler will have to decide not to retransmit (in case
* retransmission is implemented).
*
* This one assumes being called inside splimp(), and that imp >= ipl2
*/
void
@@ -1215,7 +1215,7 @@ bah_ioctl(ifp, command, data)
* retransmission is implemented).
*
- * This one assumes being called inside splimp(), and that imp >= ipl2
+ * This one assumes being called inside splnet(), and that imp >= ipl2
*/
void
diff --git a/sys/arch/amiga/dev/if_ed.c b/sys/arch/amiga/dev/if_ed.c
index 08da42a3bde..4052fced067 100644
--- a/sys/arch/amiga/dev/if_ed.c
+++ b/sys/arch/amiga/dev/if_ed.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ed.c,v 1.16 1995/10/01 19:30:22 chopps Exp $ */
+/* $NetBSD: if_ed.c,v 1.17 1995/12/24 02:29:57 mycroft Exp $ */
/*
* Device driver for National Semiconductor DS8390/WD83C690 based ethernet
@@ -277,7 +277,7 @@ ed_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
ed_stop(sc);
ed_init(sc);
splx(s);
@@ -337,7 +337,7 @@ ed_init(sc)
* This init procedure is "mandatory"...don't change what or when
* things happen.
*/
- s = splimp();
+ s = splnet();
/* Reset transmitter flags. */
sc->xmit_busy = 0;
@@ -476,7 +476,7 @@ ed_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -850,7 +850,7 @@ ed_ioctl(ifp, command, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (command) {
@@ -476,7 +476,7 @@ ed_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
diff --git a/sys/arch/mac68k/dev/if_ae.c b/sys/arch/mac68k/dev/if_ae.c
index e3b755d2015..3d798d202de 100644
--- a/sys/arch/mac68k/dev/if_ae.c
+++ b/sys/arch/mac68k/dev/if_ae.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ae.c,v 1.36 1995/09/24 14:13:58 briggs Exp $ */
+/* $NetBSD: if_ae.c,v 1.37 1995/12/24 02:30:37 mycroft Exp $ */
/*
* Device driver for National Semiconductor DS8390/WD83C690 based ethernet
@@ -451,7 +451,7 @@ aereset(sc)
{
int s;
- s = splimp();
+ s = splnet();
aestop(sc);
aeinit(sc);
splx(s);
@@ -664,7 +664,7 @@ ae_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1025,7 +1025,7 @@ aeioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *) data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -664,7 +664,7 @@ ae_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
diff --git a/sys/arch/sparc/dev/if_ie.c b/sys/arch/sparc/dev/if_ie.c
index b959acb8e36..6922937784c 100644
--- a/sys/arch/sparc/dev/if_ie.c
+++ b/sys/arch/sparc/dev/if_ie.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie.c,v 1.16 1995/12/11 12:43:26 pk Exp $ */
+/* $NetBSD: if_ie.c,v 1.17 1995/12/24 02:30:45 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum.
@@ -92,7 +92,7 @@ Mode of operation:
shall have the I (IE_CMD_INTR) bit set in the command. This way,
when an interrupt arrives at ieintr(), it is immediately possible
to tell what precisely caused it. ANY OTHER command-sending
- routines should run at splimp(), and should post an acknowledgement
+ routines should run at splnet(), and should post an acknowledgement
to every interrupt they generate.
*/
@@ -1447,7 +1447,7 @@ ie_setupram(sc)
volatile struct ie_sys_ctl_block *scb;
int s;
- s = splimp();
+ s = splnet();
scp = sc->scp;
(sc->memzero)((char *) scp, sizeof *scp);
@@ -1487,7 +1487,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
printf("%s: reset\n", sc->sc_dev.dv_xname);
@@ -1555,7 +1555,7 @@ command_and_wait(sc, cmd, pcmd, mask)
/*
* XXX
* I don't think this timeout works on suns.
* we are at splimp() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1791,7 +1791,7 @@ setup_bufs(sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -1826,7 +1826,7 @@ mc_setup(sc, ptr)
* includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands, starting
* the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -1928,7 +1928,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch(cmd) {
@@ -1555,7 +1555,7 @@ command_and_wait(sc, cmd, pcmd, mask)
* XXX
* I don't think this timeout works on suns.
- * we are at splimp() in the loop, and the timeout
+ * we are at splnet() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1826,7 +1826,7 @@ mc_setup(sc, ptr)
* the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int
diff --git a/sys/arch/sun3/dev/if_ie.c b/sys/arch/sun3/dev/if_ie.c
index 2a4135f607a..10ecdf0e7f1 100644
--- a/sys/arch/sun3/dev/if_ie.c
+++ b/sys/arch/sun3/dev/if_ie.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie.c,v 1.5 1995/04/11 06:05:11 mycroft Exp $ */
+/* $NetBSD: if_ie.c,v 1.6 1995/12/24 02:30:48 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum.
@@ -92,7 +92,7 @@
shall have the I (IE_CMD_INTR) bit set in the command. This way,
when an interrupt arrives at ieintr(), it is immediately possible
to tell what precisely caused it. ANY OTHER command-sending
- routines should run at splimp(), and should post an acknowledgement
+ routines should run at splnet(), and should post an acknowledgement
to every interrupt they generate.
*/
@@ -1084,7 +1084,7 @@ ie_setupram(sc)
volatile struct ie_sys_ctl_block *scb;
int s;
- s = splimp();
+ s = splnet();
scp = sc->scp;
(sc->sc_bzero)((char *) scp, sizeof *scp);
@@ -1124,7 +1124,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
printf("%s: reset\n", sc->sc_dev.dv_xname);
@@ -1191,7 +1191,7 @@ command_and_wait(sc, cmd, pcmd, mask)
/*
* XXX
* I don't think this timeout works on suns.
* we are at splimp() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1413,7 +1413,7 @@ setup_bufs(sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -1447,7 +1447,7 @@ mc_setup(sc, ptr)
* This includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands,
* starting the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -1550,7 +1550,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *) data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -1191,7 +1191,7 @@ command_and_wait(sc, cmd, pcmd, mask)
* XXX
* I don't think this timeout works on suns.
- * we are at splimp() in the loop, and the timeout
+ * we are at splnet() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1447,7 +1447,7 @@ mc_setup(sc, ptr)
* starting the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int
diff --git a/sys/dev/ic/mb86960.c b/sys/dev/ic/mb86960.c
index 4f10f48f143..2a853fe9d36 100644
--- a/sys/dev/ic/mb86960.c
+++ b/sys/dev/ic/mb86960.c
@@ -1124,8 +1124,8 @@ feattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- feintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, feintr,
+ sc);
}
/*
@@ -1137,7 +1137,7 @@ fe_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
fe_stop(sc);
fe_init(sc);
splx(s);
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1928,7 +1928,7 @@ fe_ioctl(ifp, command, data)
log(LOG_INFO, "%s: ioctl(%x)\n", sc->sc_dev.dv_xname, command);
#endif
- s = splimp();
+ s = splnet();
switch (command) {
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
/*
* Load a new multicast address filter into MARs.
*
* The caller must have splimp'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
* a device is RUNNING. (I mistook the point in previous versions.)
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
* Load a new multicast address filter into MARs.
*
- * The caller must have splimp'ed befor fe_loadmar.
+ * The caller must have splnet'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
diff --git a/sys/dev/ic/mb86960var.h b/sys/dev/ic/mb86960var.h
index 4f10f48f143..2a853fe9d36 100644
--- a/sys/dev/ic/mb86960var.h
+++ b/sys/dev/ic/mb86960var.h
@@ -1124,8 +1124,8 @@ feattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- feintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, feintr,
+ sc);
}
/*
@@ -1137,7 +1137,7 @@ fe_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
fe_stop(sc);
fe_init(sc);
splx(s);
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1928,7 +1928,7 @@ fe_ioctl(ifp, command, data)
log(LOG_INFO, "%s: ioctl(%x)\n", sc->sc_dev.dv_xname, command);
#endif
- s = splimp();
+ s = splnet();
switch (command) {
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
/*
* Load a new multicast address filter into MARs.
*
* The caller must have splimp'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
* a device is RUNNING. (I mistook the point in previous versions.)
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
* Load a new multicast address filter into MARs.
*
- * The caller must have splimp'ed befor fe_loadmar.
+ * The caller must have splnet'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
diff --git a/sys/dev/ic/smc90cx6.c b/sys/dev/ic/smc90cx6.c
index 649bfa819fb..86149e577b5 100644
--- a/sys/dev/ic/smc90cx6.c
+++ b/sys/dev/ic/smc90cx6.c
@@ -1,4 +1,4 @@
-/* $NetBSD: smc90cx6.c,v 1.12 1995/10/09 15:20:25 chopps Exp $ */
+/* $NetBSD: smc90cx6.c,v 1.13 1995/12/24 02:29:55 mycroft Exp $ */
/*
* Copyright (c) 1994, 1995 Ignatios Souvatzis
@@ -309,7 +309,7 @@ bah_init(sc)
ifp = &sc->sc_arccom.ac_if;
if ((ifp->if_flags & IFF_RUNNING) == 0) {
- s = splimp();
+ s = splnet();
ifp->if_flags |= IFF_RUNNING;
bah_reset(sc);
bah_start(ifp);
@@ -548,7 +548,7 @@ bah_start(ifp)
if ((ifp->if_flags & IFF_RUNNING) == 0)
return;
- s = splimp();
+ s = splnet();
if (sc->sc_tx_fillcount >= 2) {
splx(s);
@@ -643,7 +643,7 @@ bah_start(ifp)
sc->sc_retransmits[buffer] = (m->m_flags & M_BCAST) ? 1 : 5;
/* actually transmit the packet */
- s = splimp();
+ s = splnet();
if (++sc->sc_tx_fillcount > 1) {
/*
@@ -780,7 +780,7 @@ bah_srint(sc, dummy)
head = 0;
ifp = &sc->sc_arccom.ac_if;
- s = splimp();
+ s = splnet();
if (sc->sc_rx_fillcount <= 1)
buffer = sc->sc_rx_act ^ 1;
else {
@@ -909,7 +909,7 @@ cleanup:
if (head == NULL)
m_freem(head);
- s = splimp();
+ s = splnet();
if (--sc->sc_rx_fillcount == 1) {
@@ -1152,7 +1152,7 @@ bah_ioctl(ifp, command, data)
error = 0;
sc = bahcd.cd_devs[ifp->if_unit];
ifa = (struct ifaddr *)data;
- s = splimp();
+ s = splnet();
#if defined(BAH_DEBUG) && (BAH_DEBUG > 2)
printf("%s: ioctl() called, cmd = 0x%x\n",
@@ -1215,7 +1215,7 @@ bah_ioctl(ifp, command, data)
* and the int handler will have to decide not to retransmit (in case
* retransmission is implemented).
*
* This one assumes being called inside splimp(), and that imp >= ipl2
*/
void
@@ -1215,7 +1215,7 @@ bah_ioctl(ifp, command, data)
* retransmission is implemented).
*
- * This one assumes being called inside splimp(), and that imp >= ipl2
+ * This one assumes being called inside splnet(), and that imp >= ipl2
*/
void
diff --git a/sys/dev/isa/if_ate.c b/sys/dev/isa/if_ate.c
index 4f10f48f143..2a853fe9d36 100644
--- a/sys/dev/isa/if_ate.c
+++ b/sys/dev/isa/if_ate.c
@@ -1124,8 +1124,8 @@ feattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- feintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, feintr,
+ sc);
}
/*
@@ -1137,7 +1137,7 @@ fe_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
fe_stop(sc);
fe_init(sc);
splx(s);
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1928,7 +1928,7 @@ fe_ioctl(ifp, command, data)
log(LOG_INFO, "%s: ioctl(%x)\n", sc->sc_dev.dv_xname, command);
#endif
- s = splimp();
+ s = splnet();
switch (command) {
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
/*
* Load a new multicast address filter into MARs.
*
* The caller must have splimp'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
* a device is RUNNING. (I mistook the point in previous versions.)
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
* Load a new multicast address filter into MARs.
*
- * The caller must have splimp'ed befor fe_loadmar.
+ * The caller must have splnet'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
diff --git a/sys/dev/isa/if_ed.c b/sys/dev/isa/if_ed.c
index 0c4fa0cd428..8918609f049 100644
--- a/sys/dev/isa/if_ed.c
+++ b/sys/dev/isa/if_ed.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ed.c,v 1.85 1995/07/25 05:11:11 mycroft Exp $ */
+/* $NetBSD: if_ed.c,v 1.86 1995/12/24 02:31:21 mycroft Exp $ */
/*
* Device driver for National Semiconductor DS8390/WD83C690 based ethernet
@@ -1092,8 +1092,8 @@ edattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- edintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, edintr,
+ sc);
}
/*
@@ -1105,7 +1105,7 @@ edreset(sc)
{
int s;
- s = splimp();
+ s = splnet();
edstop(sc);
edinit(sc);
splx(s);
@@ -1329,7 +1329,7 @@ ed_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1766,7 +1766,7 @@ edioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -1329,7 +1329,7 @@ ed_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
diff --git a/sys/dev/isa/if_el.c b/sys/dev/isa/if_el.c
index 0a6d9d27fc3..574c9452be7 100644
--- a/sys/dev/isa/if_el.c
+++ b/sys/dev/isa/if_el.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_el.c,v 1.33 1995/08/05 23:53:18 mycroft Exp $ */
+/* $NetBSD: if_el.c,v 1.34 1995/12/24 02:31:25 mycroft Exp $ */
/*
* Copyright (c) 1994, Matthew E. Kimmel. Permission is hereby granted
@@ -205,8 +205,8 @@ elattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- elintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, elintr,
+ sc);
dprintf(("elattach() finished.\n"));
}
@@ -221,7 +221,7 @@ elreset(sc)
int s;
dprintf(("elreset()\n"));
- s = splimp();
+ s = splnet();
elstop(sc);
elinit(sc);
splx(s);
@@ -296,7 +296,7 @@ elinit(sc)
/*
* Start output on interface. Get datagrams from the queue and output them,
* giving the receiver a chance between datagrams. Call only from splimp or
* interrupt level!
*/
void
@@ -309,7 +309,7 @@ elstart(ifp)
int s, i, off, retries;
dprintf(("elstart()...\n"));
- s = splimp();
+ s = splnet();
/* Don't do anything if output is active. */
if ((ifp->if_flags & IFF_OACTIVE) != 0) {
@@ -392,7 +392,7 @@ elstart(ifp)
outb(iobase+EL_AC, EL_AC_IRQE | EL_AC_RX);
splx(s);
/* Interrupt here. */
- s = splimp();
+ s = splnet();
}
(void)inb(iobase+EL_AS);
@@ -403,7 +403,7 @@ elstart(ifp)
/*
* This function actually attempts to transmit a datagram downloaded to the
* board. Call at splimp or interrupt, after downloading data! Returns 0 on
* success, non-0 on failure.
*/
static int
@@ -620,7 +620,7 @@ elioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -296,7 +296,7 @@ elinit(sc)
/*
* Start output on interface. Get datagrams from the queue and output them,
- * giving the receiver a chance between datagrams. Call only from splimp or
+ * giving the receiver a chance between datagrams. Call only from splnet or
* interrupt level!
*/
@@ -403,7 +403,7 @@ elstart(ifp)
/*
* This function actually attempts to transmit a datagram downloaded to the
- * board. Call at splimp or interrupt, after downloading data! Returns 0 on
+ * board. Call at splnet or interrupt, after downloading data! Returns 0 on
* success, non-0 on failure.
*/
diff --git a/sys/dev/isa/if_ep.c b/sys/dev/isa/if_ep.c
index f3edf1424b6..83bf1338352 100644
--- a/sys/dev/isa/if_ep.c
+++ b/sys/dev/isa/if_ep.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ep.c,v 1.85 1995/12/05 03:30:15 christos Exp $ */
+/* $NetBSD: if_ep.c,v 1.86 1995/12/24 02:31:27 mycroft Exp $ */
/*
* Copyright (c) 1994 Herb Peyerl <hpeyerl@novatel.ca>
@@ -428,7 +428,7 @@ epattach(parent, self, aux)
PCI_COMMAND_STATUS_REG) |
PCI_COMMAND_MASTER_ENABLE);
- sc->sc_ih = pci_map_int(pa->pa_tag, PCI_IPL_NET, epintr, sc);
+ sc->sc_ih = pci_map_int(pa->pa_tag, IPL_NET, epintr, sc);
if (sc->sc_ih == NULL) {
printf("%s: couldn't map interrupt\n",
sc->sc_dev.dv_xname);
@@ -440,8 +440,8 @@ epattach(parent, self, aux)
#endif
{
struct isa_attach_args *ia = aux;
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE,
- ISA_IPL_NET, epintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET,
+ epintr, sc);
}
}
@@ -569,7 +569,7 @@ epsetlink(sc)
/*
* Start outputting on the interface.
* Always called as splimp().
*/
void
epstart(ifp)
@@ -1064,7 +1064,7 @@ epioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -1159,7 +1159,7 @@ epreset(sc)
{
int s;
- s = splimp();
+ s = splnet();
epstop(sc);
epinit(sc);
splx(s);
@@ -1263,7 +1263,7 @@ epmbuffill(sc)
{
int s, i;
- s = splimp();
+ s = splnet();
i = sc->last_mb;
do {
if (sc->mb[i] == NULL)
@@ -1285,7 +1285,7 @@ epmbufempty(sc)
{
int s, i;
- s = splimp();
+ s = splnet();
for (i = 0; i<MAX_MBS; i++) {
if (sc->mb[i]) {
m_freem(sc->mb[i]);
@@ -569,7 +569,7 @@ epsetlink(sc)
/*
* Start outputting on the interface.
- * Always called as splimp().
+ * Always called as splnet().
*/
void
diff --git a/sys/dev/isa/if_fe.c b/sys/dev/isa/if_fe.c
index 4f10f48f143..2a853fe9d36 100644
--- a/sys/dev/isa/if_fe.c
+++ b/sys/dev/isa/if_fe.c
@@ -1124,8 +1124,8 @@ feattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- feintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, feintr,
+ sc);
}
/*
@@ -1137,7 +1137,7 @@ fe_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
fe_stop(sc);
fe_init(sc);
splx(s);
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1928,7 +1928,7 @@ fe_ioctl(ifp, command, data)
log(LOG_INFO, "%s: ioctl(%x)\n", sc->sc_dev.dv_xname, command);
#endif
- s = splimp();
+ s = splnet();
switch (command) {
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
/*
* Load a new multicast address filter into MARs.
*
* The caller must have splimp'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
* a device is RUNNING. (I mistook the point in previous versions.)
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
* Load a new multicast address filter into MARs.
*
- * The caller must have splimp'ed befor fe_loadmar.
+ * The caller must have splnet'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
diff --git a/sys/dev/isa/if_fmv.c b/sys/dev/isa/if_fmv.c
index 4f10f48f143..2a853fe9d36 100644
--- a/sys/dev/isa/if_fmv.c
+++ b/sys/dev/isa/if_fmv.c
@@ -1124,8 +1124,8 @@ feattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- feintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, feintr,
+ sc);
}
/*
@@ -1137,7 +1137,7 @@ fe_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
fe_stop(sc);
fe_init(sc);
splx(s);
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
/*
* Start output on interface.
* We make two assumptions here:
* 1) that the current priority is set to splimp _before_ this code
* is called *and* is returned to the appropriate priority after
* return
* 2) that the IFF_OACTIVE flag is checked before this code is called
@@ -1928,7 +1928,7 @@ fe_ioctl(ifp, command, data)
log(LOG_INFO, "%s: ioctl(%x)\n", sc->sc_dev.dv_xname, command);
#endif
- s = splimp();
+ s = splnet();
switch (command) {
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
/*
* Load a new multicast address filter into MARs.
*
* The caller must have splimp'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
* a device is RUNNING. (I mistook the point in previous versions.)
@@ -1410,7 +1410,7 @@ fe_xmit(sc)
* Start output on interface.
* We make two assumptions here:
- * 1) that the current priority is set to splimp _before_ this code
+ * 1) that the current priority is set to splnet _before_ this code
* is called *and* is returned to the appropriate priority after
* return
@@ -2427,7 +2427,7 @@ fe_setmode(sc)
* Load a new multicast address filter into MARs.
*
- * The caller must have splimp'ed befor fe_loadmar.
+ * The caller must have splnet'ed befor fe_loadmar.
* This function starts the DLC upon return. So it can be called only
* when the chip is working, i.e., from the driver's point of view, when
diff --git a/sys/dev/isa/if_hp.c b/sys/dev/isa/if_hp.c
index d0117ae2839..86f9916044f 100644
--- a/sys/dev/isa/if_hp.c
+++ b/sys/dev/isa/if_hp.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_hp.c,v 1.20 1995/04/17 12:09:01 cgd Exp $ */
+/* $NetBSD: if_hp.c,v 1.21 1995/12/24 02:31:31 mycroft Exp $ */
/* XXX THIS DRIVER IS BROKEN. IT WILL NOT EVEN COMPILE. */
@@ -162,7 +162,7 @@ hpprobe(dvp)
#endif
hpc = (ns->ns_port = dvp->id_iobase + 0x10);
- s = splimp();
+ s = splnet();
ns->hp_irq = ffs(dvp->id_irq) - 1;
@@ -441,7 +441,7 @@ hpinit(unit)
if (ifp->if_flags & IFF_RUNNING)
return;
- s = splimp();
+ s = splnet();
#ifdef HP_DEBUG
printf("hpinit: hp%d at 0x%x irq %d\n", unit, hpc, (int) ns->hp_irq);
@@ -505,7 +505,7 @@ hpinit(unit)
* Setup output on interface.
* Get another datagram to send off of the interface queue,
* and map it to the interface before starting the output.
* called only at splimp or interrupt level.
*/
hpstart(ifp)
struct ifnet *ifp;
@@ -926,7 +926,7 @@ hpioctl(ifp, cmd, data)
register struct ifaddr *ifa = (struct ifaddr *) data;
struct hp_softc *ns = &hp_softc[ifp->if_unit];
struct ifreq *ifr = (struct ifreq *) data;
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
@@ -505,7 +505,7 @@ hpinit(unit)
* Get another datagram to send off of the interface queue,
* and map it to the interface before starting the output.
- * called only at splimp or interrupt level.
+ * called only at splnet or interrupt level.
*/
hpstart(ifp)
diff --git a/sys/dev/isa/if_ie.c b/sys/dev/isa/if_ie.c
index b991ee87636..9fa3dd13963 100644
--- a/sys/dev/isa/if_ie.c
+++ b/sys/dev/isa/if_ie.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie.c,v 1.44 1995/09/26 13:24:48 hpeyerl Exp $ */
+/* $NetBSD: if_ie.c,v 1.45 1995/12/24 02:31:33 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum.
@@ -87,7 +87,7 @@ that we must include this header in the transmit buffer as well.
By convention, all transmit commands, and only transmit commands, shall have
the I (IE_CMD_INTR) bit set in the command. This way, when an interrupt
arrives at ieintr(), it is immediately possible to tell what precisely caused
-it. ANY OTHER command-sending routines should run at splimp(), and should
+it. ANY OTHER command-sending routines should run at splnet(), and should
post an acknowledgement to every interrupt they generate.
The 82586 has a 24-bit address space internally, and the adaptor's memory is
@@ -776,8 +776,8 @@ ieattach(parent, self, aux)
sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- ieintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, ieintr,
+ sc);
}
/*
@@ -1508,7 +1508,7 @@ check_ie_present(sc, where, size)
u_long realbase;
int s;
- s = splimp();
+ s = splnet();
realbase = (u_long)where + size - (1 << 24);
@@ -1759,7 +1759,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
iestop(sc);
@@ -1967,7 +1967,7 @@ iememinit(ptr, sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -2001,7 +2001,7 @@ mc_setup(sc, ptr)
* includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands, starting
* the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -2115,7 +2115,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -2001,7 +2001,7 @@ mc_setup(sc, ptr)
* the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int